@@ -4,8 +4,9 @@ from .tex_environment import TexEnvironment, Label
 
 # Other features
 from .document import Document, Section, Subsection
-from .color import Color
+from .color import *
+from .colormap import *
 from .floating_environment import FloatingFigure, FloatingTable, FloatingEnvironmentMixin
 from .plot import Plot, LinePlot, MatrixPlot
 from .template import Template
-from .table import Table
+from .table import Table, Tabular
